@@ -19,10 +19,10 @@ class VectorRange:
         return self.vector[self.startindex + key]
 
     def __iter__(self):
-        return iter(self.vector)
+        return iter(self.vector[self.startindex:self.endindex+1])
 
     def __len__(self):
         return abs(self.startindex - self.endindex) + 1
 
     def __str__(self):
-        return "< VectorRange : {0} [{1} : {2}]>".format(self.vector.id, self.startindex, self.endindex)
\ No newline at end of file
+        return "< VectorRange : {0} [{1} : {2}]>".format(self.vector.id, self.startindex, self.endindex)
