@@ -1,4 +1,4 @@
-from lfr.compiler.fluid import Fluid
+from lfr.fig.fignode import Flow, Storage, Signal
 from lfr.compiler.language.concatenation import Concatenation
 from lfr.compiler.language.fluidexpression import FluidExpression
 from lfr.compiler.language.utils import is_number
@@ -7,11 +7,10 @@ from lfr.compiler.language.vectorrange import VectorRange
 from lfr.compiler.lfrerror import ErrorType, LFRError
 from lfr.compiler.module import Module
 from lfr.compiler.moduleio import IOType, ModuleIO
-from lfr.compiler.storage import Storage
-from lfr.compiler.signal import Signal
 from enum import Enum
 from typing import List
-
+from lfr.compiler.distribute.BitVector import BitVector
+import re
 from lfr.antlrgen.lfrXListener import lfrXListener
 from lfr.antlrgen.lfrXParser import lfrXParser
 
@@ -56,9 +55,6 @@ class LFRCompiler(lfrXListener):
 
         self.typeMap = dict()
 
-        # Performance Constraints
-        self.current_performance_constraints = []
-
         # This might be the new expression stack
         self.stack = []
         self.statestack = []
@@ -66,7 +62,7 @@ class LFRCompiler(lfrXListener):
 
     def enterModuledefinition(self, ctx: lfrXParser.ModuledefinitionContext):
         m = Module(ctx.ID().getText())
-        self.modules.append(m)
+        # self.modules.append(m)
         self.currentModule = m
 
     def exitModuledefinition(self, ctx: lfrXParser.ModuledefinitionContext):
@@ -161,7 +157,7 @@ class LFRCompiler(lfrXListener):
                 startindex = int(declvar.vector().start.text)
                 endindex = int(declvar.vector().end.text)
 
-            v = self.__createVector(name, Fluid, startindex, endindex)
+            v = self.__createVector(name, Flow, startindex, endindex)
 
             for item in v.get_items():
                 self.currentModule.add_fluid(item)
@@ -224,10 +220,6 @@ class LFRCompiler(lfrXListener):
         startindex = 0
         endindex = 0
 
-        if ctx.vector() is not None:
-            startindex = int(ctx.vector().start.text)
-            endindex = int(ctx.vector().end.text)
-
         if name in self.vectors:
             v = self.vectors[name]
             startindex = v.startindex
@@ -235,6 +227,14 @@ class LFRCompiler(lfrXListener):
         else:
             raise Exception("Trying to parse vector variable {} and we couldn't find the vector in itself: Line - {}".format(name, ctx.start.line))
 
+        # Check to see if the slice is present utilize the index
+        if ctx.vector() is not None:
+            startindex = int(ctx.vector().start.text)
+            if ctx.vector().end is not None:
+                endindex = int(ctx.vector().end.text)
+            else:
+                endindex = startindex
+
         vrange = VectorRange(v, startindex, endindex)
 
         self.stack.append(vrange)
@@ -281,7 +281,7 @@ class LFRCompiler(lfrXListener):
             n = int(ctx.Hex_number().getText(), 16)
 
         elif ctx.Binary_number() is not None:
-            n = int(ctx.Binary_number().getText(), 2)
+            n = self.__parseBinaryNumber(ctx.Binary_number().getText())
 
         else:
             n = float(ctx.Real_number().getText())
@@ -334,15 +334,13 @@ class LFRCompiler(lfrXListener):
         stackslice = self.stack[-(len(self.binaryoperatorsstack[-1])+1):]
         del self.stack[-(len(self.binaryoperatorsstack[-1])+1):]
 
-        fluidexpression = FluidExpression(self.currentModule, self.current_performance_constraints)
+        fluidexpression = FluidExpression(self.currentModule)
         # TODO: Figure out how to pass the FIG after this
         result = fluidexpression.process_expression(stackslice, self.binaryoperatorsstack[-1])
         self.stack.append(result)
 
         self.binaryoperatorsstack.pop()
 
-        self.current_performance_constraints.clear()
-
     def enterBracketexpression(self, ctx: lfrXParser.BracketexpressionContext):
         self.__updateMode(ListenerMode.EXPRESS_PARSING_MODE)
 
@@ -475,3 +473,11 @@ class LFRCompiler(lfrXListener):
             print(item)
 
         print('---Bottom of Stack---')
+
+    def __parseBinaryNumber(self, text: str) -> BitVector:
+        pattern = r"(\d+)'b(\d+)"
+        matches = re.search(pattern, text)
+        # size = int(matches.group(1))
+        bit_pattern = matches.group(2)
+        n = BitVector(bitstring=bit_pattern)
+        return n
